@@ -1,14 +1,20 @@
-
 from PyObjCTools.TestSupport import *
 from QTKit import *
 
-class TestQTFormatDescription (TestCase):
+
+class TestQTFormatDescription(TestCase):
     def testConstants(self):
-        self.assertIsInstance(QTFormatDescriptionAudioStreamBasicDescriptionAttribute, unicode)
+        self.assertIsInstance(
+            QTFormatDescriptionAudioStreamBasicDescriptionAttribute, unicode
+        )
         self.assertIsInstance(QTFormatDescriptionAudioMagicCookieAttribute, unicode)
         self.assertIsInstance(QTFormatDescriptionAudioChannelLayoutAttribute, unicode)
-        self.assertIsInstance(QTFormatDescriptionVideoCleanApertureDisplaySizeAttribute, unicode)
-        self.assertIsInstance(QTFormatDescriptionVideoProductionApertureDisplaySizeAttribute, unicode)
+        self.assertIsInstance(
+            QTFormatDescriptionVideoCleanApertureDisplaySizeAttribute, unicode
+        )
+        self.assertIsInstance(
+            QTFormatDescriptionVideoProductionApertureDisplaySizeAttribute, unicode
+        )
         self.assertIsInstance(QTFormatDescriptionVideoEncodedPixelsSizeAttribute, unicode)
 
     def testMethods(self):
